@@ -15,7 +15,7 @@ from thefuck.specific.sudo import sudo_support
 @sudo_support
 def match(command):
     return (command.stderr.endswith("hard link not allowed for directory") and
-            command.script.startswith("ln "))
+            command.script_parts[0] == 'ln')
 
 
 @sudo_support
