@@ -19,9 +19,9 @@ class Tcsh(Generic):
     def get_aliases(self):
         proc = Popen(['tcsh', '-ic', 'alias'], stdout=PIPE, stderr=DEVNULL)
         return dict(
-                self._parse_alias(alias)
-                for alias in proc.stdout.read().decode('utf-8').split('\n')
-                if alias and '\t' in alias)
+            self._parse_alias(alias)
+            for alias in proc.stdout.read().decode('utf-8').split('\n')
+            if alias and '\t' in alias)
 
     def _get_history_file_name(self):
         return os.environ.get("HISTFILE",
@@ -31,4 +31,7 @@ class Tcsh(Generic):
         return u'#+{}\n{}\n'.format(int(time()), command_script)
 
     def how_to_configure(self):
-        return 'eval `thefuck --alias`', '~/.tcshrc'
+        return self._create_shell_configuration(
+            content=u'eval `thefuck --alias`',
+            path='~/.tcshrc',
+            reload='tcsh')
