@@ -23,9 +23,15 @@ def get_key():
     if ch == b'P':
         return const.KEY_DOWN
 
-    encoding = sys.stdout.encoding or os.environ.get('PYTHONIOENCODING', 'utf-8')
+    encoding = (sys.stdout.encoding
+                or os.environ.get('PYTHONIOENCODING', 'utf-8'))
     return ch.decode(encoding)
 
+
+def open_command(arg):
+    return 'cmd /c start ' + arg
+
+
 try:
     from pathlib import Path
 except ImportError:
@@ -35,5 +41,6 @@ except ImportError:
 def _expanduser(self):
     return self.__class__(os.path.expanduser(str(self)))
 
+
 # pathlib's expanduser fails on windows, see http://bugs.python.org/issue19776
 Path.expanduser = _expanduser
